@@ -22,6 +22,7 @@ from .literals import (
     AttachmentStateType,
     AttachmentTypeType,
     CoreNetworkPolicyAliasType,
+    PeeringStateType,
     RouteStateType,
     RouteTypeType,
 )
@@ -29,6 +30,7 @@ from .paginator import (
     DescribeGlobalNetworksPaginator,
     GetConnectionsPaginator,
     GetConnectPeerAssociationsPaginator,
+    GetCoreNetworkChangeEventsPaginator,
     GetCoreNetworkChangeSetPaginator,
     GetCustomerGatewayAssociationsPaginator,
     GetDevicesPaginator,
@@ -45,6 +47,7 @@ from .paginator import (
     ListConnectPeersPaginator,
     ListCoreNetworkPolicyVersionsPaginator,
     ListCoreNetworksPaginator,
+    ListPeeringsPaginator,
 )
 from .type_defs import (
     AcceptAttachmentResponseTypeDef,
@@ -65,6 +68,8 @@ from .type_defs import (
     CreateLinkResponseTypeDef,
     CreateSiteResponseTypeDef,
     CreateSiteToSiteVpnAttachmentResponseTypeDef,
+    CreateTransitGatewayPeeringResponseTypeDef,
+    CreateTransitGatewayRouteTableAttachmentResponseTypeDef,
     CreateVpcAttachmentResponseTypeDef,
     DeleteAttachmentResponseTypeDef,
     DeleteConnectionResponseTypeDef,
@@ -74,6 +79,7 @@ from .type_defs import (
     DeleteDeviceResponseTypeDef,
     DeleteGlobalNetworkResponseTypeDef,
     DeleteLinkResponseTypeDef,
+    DeletePeeringResponseTypeDef,
     DeleteSiteResponseTypeDef,
     DeregisterTransitGatewayResponseTypeDef,
     DescribeGlobalNetworksResponseTypeDef,
@@ -85,6 +91,7 @@ from .type_defs import (
     GetConnectionsResponseTypeDef,
     GetConnectPeerAssociationsResponseTypeDef,
     GetConnectPeerResponseTypeDef,
+    GetCoreNetworkChangeEventsResponseTypeDef,
     GetCoreNetworkChangeSetResponseTypeDef,
     GetCoreNetworkPolicyResponseTypeDef,
     GetCoreNetworkResponseTypeDef,
@@ -102,12 +109,16 @@ from .type_defs import (
     GetSitesResponseTypeDef,
     GetSiteToSiteVpnAttachmentResponseTypeDef,
     GetTransitGatewayConnectPeerAssociationsResponseTypeDef,
+    GetTransitGatewayPeeringResponseTypeDef,
     GetTransitGatewayRegistrationsResponseTypeDef,
+    GetTransitGatewayRouteTableAttachmentResponseTypeDef,
     GetVpcAttachmentResponseTypeDef,
     ListAttachmentsResponseTypeDef,
     ListConnectPeersResponseTypeDef,
     ListCoreNetworkPolicyVersionsResponseTypeDef,
     ListCoreNetworksResponseTypeDef,
+    ListOrganizationServiceAccessStatusResponseTypeDef,
+    ListPeeringsResponseTypeDef,
     ListTagsForResourceResponseTypeDef,
     LocationTypeDef,
     PutCoreNetworkPolicyResponseTypeDef,
@@ -116,6 +127,7 @@ from .type_defs import (
     RestoreCoreNetworkPolicyVersionResponseTypeDef,
     RouteAnalysisEndpointOptionsSpecificationTypeDef,
     RouteTableIdentifierTypeDef,
+    StartOrganizationServiceAccessUpdateResponseTypeDef,
     StartRouteAnalysisResponseTypeDef,
     TagTypeDef,
     UpdateConnectionResponseTypeDef,
@@ -238,14 +250,22 @@ class NetworkManagerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#close)
+        """
+
     def create_connect_attachment(
         self,
         *,
         CoreNetworkId: str,
         EdgeLocation: str,
         TransportAttachmentId: str,
-        Options: "ConnectAttachmentOptionsTypeDef",
-        Tags: Sequence["TagTypeDef"] = ...,
+        Options: ConnectAttachmentOptionsTypeDef,
+        Tags: Sequence[TagTypeDef] = ...,
         ClientToken: str = ...
     ) -> CreateConnectAttachmentResponseTypeDef:
         """
@@ -263,12 +283,12 @@ class NetworkManagerClient(BaseClient):
         PeerAddress: str,
         InsideCidrBlocks: Sequence[str],
         CoreNetworkAddress: str = ...,
-        BgpOptions: "BgpOptionsTypeDef" = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        BgpOptions: BgpOptionsTypeDef = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         ClientToken: str = ...
     ) -> CreateConnectPeerResponseTypeDef:
         """
-        Creates a core network connect peer for a specified core network connect
+        Creates a core network Connect peer for a specified core network connect
         attachment between a core network and an appliance.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.create_connect_peer)
@@ -284,7 +304,7 @@ class NetworkManagerClient(BaseClient):
         LinkId: str = ...,
         ConnectedLinkId: str = ...,
         Description: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateConnectionResponseTypeDef:
         """
         Creates a connection between two devices.
@@ -298,7 +318,7 @@ class NetworkManagerClient(BaseClient):
         *,
         GlobalNetworkId: str,
         Description: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         PolicyDocument: str = ...,
         ClientToken: str = ...
     ) -> CreateCoreNetworkResponseTypeDef:
@@ -314,15 +334,15 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        AWSLocation: "AWSLocationTypeDef" = ...,
+        AWSLocation: AWSLocationTypeDef = ...,
         Description: str = ...,
         Type: str = ...,
         Vendor: str = ...,
         Model: str = ...,
         SerialNumber: str = ...,
-        Location: "LocationTypeDef" = ...,
+        Location: LocationTypeDef = ...,
         SiteId: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateDeviceResponseTypeDef:
         """
         Creates a new device in a global network.
@@ -332,7 +352,7 @@ class NetworkManagerClient(BaseClient):
         """
 
     def create_global_network(
-        self, *, Description: str = ..., Tags: Sequence["TagTypeDef"] = ...
+        self, *, Description: str = ..., Tags: Sequence[TagTypeDef] = ...
     ) -> CreateGlobalNetworkResponseTypeDef:
         """
         Creates a new, empty global network.
@@ -345,12 +365,12 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        Bandwidth: "BandwidthTypeDef",
+        Bandwidth: BandwidthTypeDef,
         SiteId: str,
         Description: str = ...,
         Type: str = ...,
         Provider: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateLinkResponseTypeDef:
         """
         Creates a new link for a specified site.
@@ -364,8 +384,8 @@ class NetworkManagerClient(BaseClient):
         *,
         GlobalNetworkId: str,
         Description: str = ...,
-        Location: "LocationTypeDef" = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Location: LocationTypeDef = ...,
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateSiteResponseTypeDef:
         """
         Creates a new site in a global network.
@@ -379,24 +399,55 @@ class NetworkManagerClient(BaseClient):
         *,
         CoreNetworkId: str,
         VpnConnectionArn: str,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         ClientToken: str = ...
     ) -> CreateSiteToSiteVpnAttachmentResponseTypeDef:
         """
-        Creates a site-to-site VPN attachment on an edge location of a core network.
+        Creates an Amazon Web Services site-to-site VPN attachment on an edge location
+        of a core network.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.create_site_to_site_vpn_attachment)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#create_site_to_site_vpn_attachment)
         """
 
+    def create_transit_gateway_peering(
+        self,
+        *,
+        CoreNetworkId: str,
+        TransitGatewayArn: str,
+        Tags: Sequence[TagTypeDef] = ...,
+        ClientToken: str = ...
+    ) -> CreateTransitGatewayPeeringResponseTypeDef:
+        """
+        Creates a transit gateway peering connection.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.create_transit_gateway_peering)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#create_transit_gateway_peering)
+        """
+
+    def create_transit_gateway_route_table_attachment(
+        self,
+        *,
+        PeeringId: str,
+        TransitGatewayRouteTableArn: str,
+        Tags: Sequence[TagTypeDef] = ...,
+        ClientToken: str = ...
+    ) -> CreateTransitGatewayRouteTableAttachmentResponseTypeDef:
+        """
+        Creates a transit gateway route table attachment.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.create_transit_gateway_route_table_attachment)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#create_transit_gateway_route_table_attachment)
+        """
+
     def create_vpc_attachment(
         self,
         *,
         CoreNetworkId: str,
         VpcArn: str,
         SubnetArns: Sequence[str],
-        Options: "VpcOptionsTypeDef" = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Options: VpcOptionsTypeDef = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         ClientToken: str = ...
     ) -> CreateVpcAttachmentResponseTypeDef:
         """
@@ -474,6 +525,14 @@ class NetworkManagerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#delete_link)
         """
 
+    def delete_peering(self, *, PeeringId: str) -> DeletePeeringResponseTypeDef:
+        """
+        Deletes an existing peering connection.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.delete_peering)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#delete_peering)
+        """
+
     def delete_resource_policy(self, *, ResourceArn: str) -> Dict[str, Any]:
         """
         Deletes a resource policy for the specified resource.
@@ -623,12 +682,27 @@ class NetworkManagerClient(BaseClient):
 
     def get_core_network(self, *, CoreNetworkId: str) -> GetCoreNetworkResponseTypeDef:
         """
-        Returns information about a core network.
+        Returns information about the LIVE policy for a core network.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.get_core_network)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#get_core_network)
         """
 
+    def get_core_network_change_events(
+        self,
+        *,
+        CoreNetworkId: str,
+        PolicyVersionId: int,
+        MaxResults: int = ...,
+        NextToken: str = ...
+    ) -> GetCoreNetworkChangeEventsResponseTypeDef:
+        """
+        Returns information about a core network change event.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.get_core_network_change_events)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#get_core_network_change_events)
+        """
+
     def get_core_network_change_set(
         self,
         *,
@@ -653,7 +727,7 @@ class NetworkManagerClient(BaseClient):
         Alias: CoreNetworkPolicyAliasType = ...
     ) -> GetCoreNetworkPolicyResponseTypeDef:
         """
-        Gets details about a core network policy.
+        Returns details about a core network policy.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.get_core_network_policy)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#get_core_network_policy)
@@ -785,7 +859,7 @@ class NetworkManagerClient(BaseClient):
         self,
         *,
         GlobalNetworkId: str,
-        RouteTableIdentifier: "RouteTableIdentifierTypeDef",
+        RouteTableIdentifier: RouteTableIdentifierTypeDef,
         ExactCidrMatches: Sequence[str] = ...,
         LongestPrefixMatches: Sequence[str] = ...,
         SubnetOfMatches: Sequence[str] = ...,
@@ -881,6 +955,16 @@ class NetworkManagerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#get_transit_gateway_connect_peer_associations)
         """
 
+    def get_transit_gateway_peering(
+        self, *, PeeringId: str
+    ) -> GetTransitGatewayPeeringResponseTypeDef:
+        """
+        Returns information about a transit gateway peer.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_peering)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#get_transit_gateway_peering)
+        """
+
     def get_transit_gateway_registrations(
         self,
         *,
@@ -897,6 +981,16 @@ class NetworkManagerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#get_transit_gateway_registrations)
         """
 
+    def get_transit_gateway_route_table_attachment(
+        self, *, AttachmentId: str
+    ) -> GetTransitGatewayRouteTableAttachmentResponseTypeDef:
+        """
+        Returns information about a transit gateway route table attachment.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_route_table_attachment)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#get_transit_gateway_route_table_attachment)
+        """
+
     def get_vpc_attachment(self, *, AttachmentId: str) -> GetVpcAttachmentResponseTypeDef:
         """
         Returns information about a VPC attachment.
@@ -957,6 +1051,34 @@ class NetworkManagerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#list_core_networks)
         """
 
+    def list_organization_service_access_status(
+        self, *, MaxResults: int = ..., NextToken: str = ...
+    ) -> ListOrganizationServiceAccessStatusResponseTypeDef:
+        """
+        Gets the status of the Service Linked Role (SLR) deployment for the accounts in
+        a given Amazon Web Services Organization.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.list_organization_service_access_status)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#list_organization_service_access_status)
+        """
+
+    def list_peerings(
+        self,
+        *,
+        CoreNetworkId: str = ...,
+        PeeringType: Literal["TRANSIT_GATEWAY"] = ...,
+        EdgeLocation: str = ...,
+        State: PeeringStateType = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...
+    ) -> ListPeeringsResponseTypeDef:
+        """
+        Lists the peerings for a core network.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.list_peerings)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#list_peerings)
+        """
+
     def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
         Lists the tags for a specified resource.
@@ -1018,12 +1140,22 @@ class NetworkManagerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#restore_core_network_policy_version)
         """
 
+    def start_organization_service_access_update(
+        self, *, Action: str
+    ) -> StartOrganizationServiceAccessUpdateResponseTypeDef:
+        """
+        Enables for the Network Manager service for an Amazon Web Services Organization.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.start_organization_service_access_update)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#start_organization_service_access_update)
+        """
+
     def start_route_analysis(
         self,
         *,
         GlobalNetworkId: str,
-        Source: "RouteAnalysisEndpointOptionsSpecificationTypeDef",
-        Destination: "RouteAnalysisEndpointOptionsSpecificationTypeDef",
+        Source: RouteAnalysisEndpointOptionsSpecificationTypeDef,
+        Destination: RouteAnalysisEndpointOptionsSpecificationTypeDef,
         IncludeReturnPath: bool = ...,
         UseMiddleboxes: bool = ...
     ) -> StartRouteAnalysisResponseTypeDef:
@@ -1034,7 +1166,7 @@ class NetworkManagerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#start_route_analysis)
         """
 
-    def tag_resource(self, *, ResourceArn: str, Tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
+    def tag_resource(self, *, ResourceArn: str, Tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Tags a specified resource.
 
@@ -1081,13 +1213,13 @@ class NetworkManagerClient(BaseClient):
         *,
         GlobalNetworkId: str,
         DeviceId: str,
-        AWSLocation: "AWSLocationTypeDef" = ...,
+        AWSLocation: AWSLocationTypeDef = ...,
         Description: str = ...,
         Type: str = ...,
         Vendor: str = ...,
         Model: str = ...,
         SerialNumber: str = ...,
-        Location: "LocationTypeDef" = ...,
+        Location: LocationTypeDef = ...,
         SiteId: str = ...
     ) -> UpdateDeviceResponseTypeDef:
         """
@@ -1114,7 +1246,7 @@ class NetworkManagerClient(BaseClient):
         LinkId: str,
         Description: str = ...,
         Type: str = ...,
-        Bandwidth: "BandwidthTypeDef" = ...,
+        Bandwidth: BandwidthTypeDef = ...,
         Provider: str = ...
     ) -> UpdateLinkResponseTypeDef:
         """
@@ -1140,7 +1272,7 @@ class NetworkManagerClient(BaseClient):
         GlobalNetworkId: str,
         SiteId: str,
         Description: str = ...,
-        Location: "LocationTypeDef" = ...
+        Location: LocationTypeDef = ...
     ) -> UpdateSiteResponseTypeDef:
         """
         Updates the information for an existing site.
@@ -1155,7 +1287,7 @@ class NetworkManagerClient(BaseClient):
         AttachmentId: str,
         AddSubnetArns: Sequence[str] = ...,
         RemoveSubnetArns: Sequence[str] = ...,
-        Options: "VpcOptionsTypeDef" = ...
+        Options: VpcOptionsTypeDef = ...
     ) -> UpdateVpcAttachmentResponseTypeDef:
         """
         Updates a VPC attachment.
@@ -1189,6 +1321,15 @@ class NetworkManagerClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#get_paginator)
         """
 
+    @overload
+    def get_paginator(
+        self, operation_name: Literal["get_core_network_change_events"]
+    ) -> GetCoreNetworkChangeEventsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#get_paginator)
+        """
+
     @overload
     def get_paginator(
         self, operation_name: Literal["get_core_network_change_set"]
@@ -1326,3 +1467,10 @@ class NetworkManagerClient(BaseClient):
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.get_paginator)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#get_paginator)
         """
+
+    @overload
+    def get_paginator(self, operation_name: Literal["list_peerings"]) -> ListPeeringsPaginator:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/networkmanager.html#NetworkManager.Client.get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_networkmanager/client/#get_paginator)
+        """
